NLSL: c16pc371e.py File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Namespaces | Functions | Variables
c16pc371e.py File Reference

Go to the source code of this file.

## Namespaces
| c16pc371e

## Functions
def | c16pc371e.read_column_data (filename)

## Variables
tuple | c16pc371e.proc = Popen(['./nlsl'],stdin = PIPE, stderr = STDOUT)
tuple | c16pc371e.fp = open('c16pc371e.run')
tuple | c16pc371e.output = proc.communicate(input = fp.read())
tuple | c16pc371e.data = read_column_data('c16pc371e.spc')
list | c16pc371e.fields = data[:,0]
list | c16pc371e.experimental = data[:,1]
list | c16pc371e.fit = data[:,2]
tuple | c16pc371e.integral_of_spectrum = cumsum(experimental)
tuple | c16pc371e.normalization = abs(sum(integral_of_spectrum))
tuple | c16pc371e.fig = figure(figsize = (9,6))
list | c16pc371e.components = data[:,3:]
tuple | c16pc371e.max_of_fit = max(fit)
tuple | c16pc371e.ax = gca()
tuple | c16pc371e.ylims = ax.get_ylim()
tuple | c16pc371e.scale_integral = max_of_fit/max(integral_of_spectrum)
int | c16pc371e.loc = 2
int | c16pc371e.borderaxespad = 0
tuple | c16pc371e.rms = mean((fit/normalization-experimental/normalization)**2)
string | c16pc371e.horizontalalignment = 'left'
string | c16pc371e.verticalalignment = 'top'
| c16pc371e.transform = ax.transAxes)